@@ -87,7 +87,7 @@ To deploy a simple end-to-end example you can use the following commands
 
 ```sh
 yarn install
-projen && projen build
+projen && projen compile
 npx cdk -a lib/integ.full.js deploy -c key_name=mykey
 ```
 
@@ -121,10 +121,11 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk
-import aws_cdk.aws_iam
 import aws_cdk.aws_timestream
 import constructs
 
@@ -154,6 +155,21 @@ class Campaign(
         :param target: 
         :param auto_approve: 
         '''
+        if __debug__:
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                collection_scheme: "CollectionScheme",
+                name: builtins.str,
+                signals: typing.Sequence["CampaignSignal"],
+                target: "Vehicle",
+                auto_approve: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CampaignProps(
             collection_scheme=collection_scheme,
             name=name,
@@ -164,17 +180,17 @@ class Campaign(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="arn")
     def arn(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "arn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "name"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="target")
     def target(self) -> "Vehicle":
         return typing.cast("Vehicle", jsii.get(self, "target"))
@@ -208,6 +224,22 @@ class CampaignProps:
         :param target: 
         :param auto_approve: 
         '''
+        if __debug__:
+            def stub(
+                *,
+                collection_scheme: "CollectionScheme",
+                name: builtins.str,
+                signals: typing.Sequence["CampaignSignal"],
+                target: "Vehicle",
+                auto_approve: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument collection_scheme", value=collection_scheme, expected_type=type_hints["collection_scheme"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument signals", value=signals, expected_type=type_hints["signals"])
+            check_type(argname="argument target", value=target, expected_type=type_hints["target"])
+            check_type(argname="argument auto_approve", value=auto_approve, expected_type=type_hints["auto_approve"])
         self._values: typing.Dict[str, typing.Any] = {
             "collection_scheme": collection_scheme,
             "name": name,
@@ -273,6 +305,17 @@ class CampaignSignal(
         :param max_sample_count: -
         :param minimum_sampling_interval: -
         '''
+        if __debug__:
+            def stub(
+                name: builtins.str,
+                max_sample_count: typing.Optional[jsii.Number] = None,
+                minimum_sampling_interval: typing.Optional[aws_cdk.Duration] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument max_sample_count", value=max_sample_count, expected_type=type_hints["max_sample_count"])
+            check_type(argname="argument minimum_sampling_interval", value=minimum_sampling_interval, expected_type=type_hints["minimum_sampling_interval"])
         jsii.create(self.__class__, self, [name, max_sample_count, minimum_sampling_interval])
 
     @jsii.member(jsii_name="toObject")
@@ -291,13 +334,18 @@ class CollectionScheme(
     def to_object(self) -> typing.Mapping[typing.Any, typing.Any]:
         return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.invoke(self, "toObject", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="scheme")
     def _scheme(self) -> typing.Mapping[typing.Any, typing.Any]:
         return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.get(self, "scheme"))
 
     @_scheme.setter
     def _scheme(self, value: typing.Mapping[typing.Any, typing.Any]) -> None:
+        if __debug__:
+            def stub(value: typing.Mapping[typing.Any, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "scheme", value)
 
 
@@ -326,6 +374,20 @@ class Fleet(
         :param description: 
         :param vehicles: 
         '''
+        if __debug__:
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                fleet_id: builtins.str,
+                signal_catalog: "SignalCatalog",
+                description: typing.Optional[builtins.str] = None,
+                vehicles: typing.Optional[typing.Sequence["Vehicle"]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FleetProps(
             fleet_id=fleet_id,
             signal_catalog=signal_catalog,
@@ -335,22 +397,22 @@ class Fleet(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="arn")
     def arn(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "arn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="fleetId")
     def fleet_id(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "fleetId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signalCatalog")
     def signal_catalog(self) -> "SignalCatalog":
         return typing.cast("SignalCatalog", jsii.get(self, "signalCatalog"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vehicles")
     def vehicles(self) -> typing.Optional[typing.List["Vehicle"]]:
         return typing.cast(typing.Optional[typing.List["Vehicle"]], jsii.get(self, "vehicles"))
@@ -382,6 +444,20 @@ class FleetProps:
         :param description: 
         :param vehicles: 
         '''
+        if __debug__:
+            def stub(
+                *,
+                fleet_id: builtins.str,
+                signal_catalog: "SignalCatalog",
+                description: typing.Optional[builtins.str] = None,
+                vehicles: typing.Optional[typing.Sequence["Vehicle"]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument fleet_id", value=fleet_id, expected_type=type_hints["fleet_id"])
+            check_type(argname="argument signal_catalog", value=signal_catalog, expected_type=type_hints["signal_catalog"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument vehicles", value=vehicles, expected_type=type_hints["vehicles"])
         self._values: typing.Dict[str, typing.Any] = {
             "fleet_id": fleet_id,
             "signal_catalog": signal_catalog,
@@ -436,13 +512,18 @@ class NetworkFileDefinition(
     def to_object(self) -> typing.Mapping[typing.Any, typing.Any]:
         return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.invoke(self, "toObject", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="definition")
     def _definition(self) -> typing.Mapping[typing.Any, typing.Any]:
         return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.get(self, "definition"))
 
     @_definition.setter
     def _definition(self, value: typing.Mapping[typing.Any, typing.Any]) -> None:
+        if __debug__:
+            def stub(value: typing.Mapping[typing.Any, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "definition", value)
 
 
@@ -463,7 +544,6 @@ class SignalCatalog(
         *,
         database: aws_cdk.aws_timestream.CfnDatabase,
         nodes: typing.Sequence["SignalCatalogNode"],
-        role: aws_cdk.aws_iam.Role,
         table: aws_cdk.aws_timestream.CfnTable,
         description: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
@@ -473,15 +553,28 @@ class SignalCatalog(
         :param id: -
         :param database: 
         :param nodes: 
-        :param role: 
         :param table: 
         :param description: 
         :param name: 
         '''
+        if __debug__:
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                database: aws_cdk.aws_timestream.CfnDatabase,
+                nodes: typing.Sequence["SignalCatalogNode"],
+                table: aws_cdk.aws_timestream.CfnTable,
+                description: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = SignalCatalogProps(
             database=database,
             nodes=nodes,
-            role=role,
             table=table,
             description=description,
             name=name,
@@ -489,18 +582,18 @@ class SignalCatalog(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="arn")
     def arn(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "arn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''The name of the signal catalog.'''
         return typing.cast(builtins.str, jsii.get(self, "name"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="description")
     def description(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "description"))
@@ -517,13 +610,18 @@ class SignalCatalogNode(
     def to_object(self) -> typing.Mapping[typing.Any, typing.Any]:
         return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.invoke(self, "toObject", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="node")
     def _node(self) -> typing.Mapping[typing.Any, typing.Any]:
         return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.get(self, "node"))
 
     @_node.setter
     def _node(self, value: typing.Mapping[typing.Any, typing.Any]) -> None:
+        if __debug__:
+            def stub(value: typing.Mapping[typing.Any, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "node", value)
 
 
@@ -533,7 +631,6 @@ class SignalCatalogNode(
     name_mapping={
         "database": "database",
         "nodes": "nodes",
-        "role": "role",
         "table": "table",
         "description": "description",
         "name": "name",
@@ -545,7 +642,6 @@ class SignalCatalogProps:
         *,
         database: aws_cdk.aws_timestream.CfnDatabase,
         nodes: typing.Sequence[SignalCatalogNode],
-        role: aws_cdk.aws_iam.Role,
         table: aws_cdk.aws_timestream.CfnTable,
         description: typing.Optional[builtins.str] = None,
         name: typing.Optional[builtins.str] = None,
@@ -553,15 +649,29 @@ class SignalCatalogProps:
         '''
         :param database: 
         :param nodes: 
-        :param role: 
         :param table: 
         :param description: 
         :param name: 
         '''
+        if __debug__:
+            def stub(
+                *,
+                database: aws_cdk.aws_timestream.CfnDatabase,
+                nodes: typing.Sequence[SignalCatalogNode],
+                table: aws_cdk.aws_timestream.CfnTable,
+                description: typing.Optional[builtins.str] = None,
+                name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument database", value=database, expected_type=type_hints["database"])
+            check_type(argname="argument nodes", value=nodes, expected_type=type_hints["nodes"])
+            check_type(argname="argument table", value=table, expected_type=type_hints["table"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         self._values: typing.Dict[str, typing.Any] = {
             "database": database,
             "nodes": nodes,
-            "role": role,
             "table": table,
         }
         if description is not None:
@@ -581,12 +691,6 @@ class SignalCatalogProps:
         assert result is not None, "Required property 'nodes' is missing"
         return typing.cast(typing.List[SignalCatalogNode], result)
 
-    @builtins.property
-    def role(self) -> aws_cdk.aws_iam.Role:
-        result = self._values.get("role")
-        assert result is not None, "Required property 'role' is missing"
-        return typing.cast(aws_cdk.aws_iam.Role, result)
-
     @builtins.property
     def table(self) -> aws_cdk.aws_timestream.CfnTable:
         result = self._values.get("table")
@@ -637,6 +741,23 @@ class SignalCatalogSensor(
         :param max: -
         :param description: -
         '''
+        if __debug__:
+            def stub(
+                fully_qualified_name: builtins.str,
+                data_type: builtins.str,
+                unit: typing.Optional[builtins.str] = None,
+                min: typing.Optional[jsii.Number] = None,
+                max: typing.Optional[jsii.Number] = None,
+                description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument fully_qualified_name", value=fully_qualified_name, expected_type=type_hints["fully_qualified_name"])
+            check_type(argname="argument data_type", value=data_type, expected_type=type_hints["data_type"])
+            check_type(argname="argument unit", value=unit, expected_type=type_hints["unit"])
+            check_type(argname="argument min", value=min, expected_type=type_hints["min"])
+            check_type(argname="argument max", value=max, expected_type=type_hints["max"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
         jsii.create(self.__class__, self, [fully_qualified_name, data_type, unit, min, max, description])
 
 
@@ -649,6 +770,11 @@ class TimeBasedCollectionScheme(
         '''
         :param period: -
         '''
+        if __debug__:
+            def stub(period: aws_cdk.Duration) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument period", value=period, expected_type=type_hints["period"])
         jsii.create(self.__class__, self, [period])
 
 
@@ -675,6 +801,19 @@ class Vehicle(
         :param vehicle_model: 
         :param vehicle_name: 
         '''
+        if __debug__:
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                create_iot_thing: builtins.bool,
+                vehicle_model: "VehicleModel",
+                vehicle_name: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = VehicleProps(
             create_iot_thing=create_iot_thing,
             vehicle_model=vehicle_model,
@@ -683,42 +822,42 @@ class Vehicle(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="arn")
     def arn(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "arn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vehicleModel")
     def vehicle_model(self) -> "VehicleModel":
         return typing.cast("VehicleModel", jsii.get(self, "vehicleModel"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="vehicleName")
     def vehicle_name(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "vehicleName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="certificateArn")
     def certificate_arn(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "certificateArn"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="certificateId")
     def certificate_id(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "certificateId"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="certificatePem")
     def certificate_pem(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "certificatePem"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="endpointAddress")
     def endpoint_address(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "endpointAddress"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="privateKey")
     def private_key(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "privateKey"))
@@ -735,13 +874,18 @@ class VehicleInterface(
     def to_object(self) -> typing.Mapping[typing.Any, typing.Any]:
         return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.invoke(self, "toObject", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="intf")
     def _intf(self) -> typing.Mapping[typing.Any, typing.Any]:
         return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.get(self, "intf"))
 
     @_intf.setter
     def _intf(self, value: typing.Mapping[typing.Any, typing.Any]) -> None:
+        if __debug__:
+            def stub(value: typing.Mapping[typing.Any, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "intf", value)
 
 
@@ -772,6 +916,22 @@ class VehicleModel(
         :param network_file_definitions: 
         :param signals: 
         '''
+        if __debug__:
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                name: builtins.str,
+                network_interfaces: typing.Sequence[VehicleInterface],
+                signal_catalog: SignalCatalog,
+                description: typing.Optional[builtins.str] = None,
+                network_file_definitions: typing.Optional[typing.Sequence[NetworkFileDefinition]] = None,
+                signals: typing.Optional[typing.Sequence["VehicleSignal"]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = VehicleModelProps(
             name=name,
             network_interfaces=network_interfaces,
@@ -783,12 +943,12 @@ class VehicleModel(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "name"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signalCatalog")
     def signal_catalog(self) -> SignalCatalog:
         return typing.cast(SignalCatalog, jsii.get(self, "signalCatalog"))
@@ -825,6 +985,24 @@ class VehicleModelProps:
         :param network_file_definitions: 
         :param signals: 
         '''
+        if __debug__:
+            def stub(
+                *,
+                name: builtins.str,
+                network_interfaces: typing.Sequence[VehicleInterface],
+                signal_catalog: SignalCatalog,
+                description: typing.Optional[builtins.str] = None,
+                network_file_definitions: typing.Optional[typing.Sequence[NetworkFileDefinition]] = None,
+                signals: typing.Optional[typing.Sequence["VehicleSignal"]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument network_interfaces", value=network_interfaces, expected_type=type_hints["network_interfaces"])
+            check_type(argname="argument signal_catalog", value=signal_catalog, expected_type=type_hints["signal_catalog"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument network_file_definitions", value=network_file_definitions, expected_type=type_hints["network_file_definitions"])
+            check_type(argname="argument signals", value=signals, expected_type=type_hints["signals"])
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "network_interfaces": network_interfaces,
@@ -907,6 +1085,18 @@ class VehicleProps:
         :param vehicle_model: 
         :param vehicle_name: 
         '''
+        if __debug__:
+            def stub(
+                *,
+                create_iot_thing: builtins.bool,
+                vehicle_model: VehicleModel,
+                vehicle_name: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument create_iot_thing", value=create_iot_thing, expected_type=type_hints["create_iot_thing"])
+            check_type(argname="argument vehicle_model", value=vehicle_model, expected_type=type_hints["vehicle_model"])
+            check_type(argname="argument vehicle_name", value=vehicle_name, expected_type=type_hints["vehicle_name"])
         self._values: typing.Dict[str, typing.Any] = {
             "create_iot_thing": create_iot_thing,
             "vehicle_model": vehicle_model,
@@ -954,13 +1144,18 @@ class VehicleSignal(
     def to_object(self) -> typing.Mapping[typing.Any, typing.Any]:
         return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.invoke(self, "toObject", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="signal")
     def _signal(self) -> typing.Mapping[typing.Any, typing.Any]:
         return typing.cast(typing.Mapping[typing.Any, typing.Any], jsii.get(self, "signal"))
 
     @_signal.setter
     def _signal(self, value: typing.Mapping[typing.Any, typing.Any]) -> None:
+        if __debug__:
+            def stub(value: typing.Mapping[typing.Any, typing.Any]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "signal", value)
 
 
@@ -980,6 +1175,17 @@ class CanDefinition(
         :param signals_map: -
         :param can_dbc_files: -
         '''
+        if __debug__:
+            def stub(
+                network_interface: builtins.str,
+                signals_map: typing.Mapping[builtins.str, builtins.str],
+                can_dbc_files: typing.Sequence[builtins.str],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument network_interface", value=network_interface, expected_type=type_hints["network_interface"])
+            check_type(argname="argument signals_map", value=signals_map, expected_type=type_hints["signals_map"])
+            check_type(argname="argument can_dbc_files", value=can_dbc_files, expected_type=type_hints["can_dbc_files"])
         jsii.create(self.__class__, self, [network_interface, signals_map, can_dbc_files])
 
 
@@ -993,6 +1199,12 @@ class CanVehicleInterface(
         :param interface_id: -
         :param name: -
         '''
+        if __debug__:
+            def stub(interface_id: builtins.str, name: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument interface_id", value=interface_id, expected_type=type_hints["interface_id"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         jsii.create(self.__class__, self, [interface_id, name])
 
 
@@ -1024,6 +1236,29 @@ class CanVehicleSignal(
         :param offset: -
         :param start_bit: -
         '''
+        if __debug__:
+            def stub(
+                fully_qualified_name: builtins.str,
+                interface_id: builtins.str,
+                message_id: jsii.Number,
+                factor: jsii.Number,
+                is_big_endian: builtins.bool,
+                is_signed: builtins.bool,
+                length: jsii.Number,
+                offset: jsii.Number,
+                start_bit: jsii.Number,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument fully_qualified_name", value=fully_qualified_name, expected_type=type_hints["fully_qualified_name"])
+            check_type(argname="argument interface_id", value=interface_id, expected_type=type_hints["interface_id"])
+            check_type(argname="argument message_id", value=message_id, expected_type=type_hints["message_id"])
+            check_type(argname="argument factor", value=factor, expected_type=type_hints["factor"])
+            check_type(argname="argument is_big_endian", value=is_big_endian, expected_type=type_hints["is_big_endian"])
+            check_type(argname="argument is_signed", value=is_signed, expected_type=type_hints["is_signed"])
+            check_type(argname="argument length", value=length, expected_type=type_hints["length"])
+            check_type(argname="argument offset", value=offset, expected_type=type_hints["offset"])
+            check_type(argname="argument start_bit", value=start_bit, expected_type=type_hints["start_bit"])
         jsii.create(self.__class__, self, [fully_qualified_name, interface_id, message_id, factor, is_big_endian, is_signed, length, offset, start_bit])
 
 
@@ -1041,6 +1276,15 @@ class SignalCatalogBranch(
         :param fully_qualified_name: -
         :param description: -
         '''
+        if __debug__:
+            def stub(
+                fully_qualified_name: builtins.str,
+                description: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument fully_qualified_name", value=fully_qualified_name, expected_type=type_hints["fully_qualified_name"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
         jsii.create(self.__class__, self, [fully_qualified_name, description])
 
 
