@@ -3,7 +3,6 @@ import * as path from 'path';
 import * as cdk from 'aws-cdk-lib';
 import {
   aws_timestream as ts,
-  aws_iam as iam,
 } from 'aws-cdk-lib';
 import * as ifw from '.';
 
@@ -33,28 +32,6 @@ export class IntegTesting {
 
     table.node.addDependency(database);
 
-    const role = new iam.Role(stack, 'Role', {
-      roleName: 'iotfleetwise-role',
-      assumedBy: new iam.ServicePrincipal('iotfleetwise.amazonaws.com'),
-    });
-
-    role.addToPolicy(new iam.PolicyStatement({
-      effect: iam.Effect.ALLOW,
-      actions: [
-        'timestream:WriteRecords',
-        'timestream:Select',
-      ],
-      resources: ['*'],
-    }));
-
-    role.addToPolicy(new iam.PolicyStatement({
-      effect: iam.Effect.ALLOW,
-      actions: [
-        'timestream:DescribeEndpoints',
-      ],
-      resources: ['*'],
-    }));
-
     const canDbc = fs.readFileSync(path.join(__dirname, '/../hscan.dbc'), 'utf8');
 
     const nodes: Array<ifw.SignalCatalogNode> = [new ifw.SignalCatalogBranch('Vehicle', 'Vehicle')];
@@ -66,7 +43,6 @@ export class IntegTesting {
     const signalCatalog = new ifw.SignalCatalog(stack, 'SignalCatalog', {
       database,
       table,
-      role,
       description: 'my signal catalog',
       nodes,
     });
